summaryrefslogtreecommitdiff
path: root/src/arch/x86/processor.h
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2009-05-17 22:59:55 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2009-05-17 22:59:55 (GMT)
commit4d0ff0c23862c242d533d9b2d34e8812ef99ad61 (patch)
tree3b8504b8d3946a8bc9a702b819138ab1e5501be6 /src/arch/x86/processor.h
parent96cb6971ee3ca529958b8cb1e8e55a6eb4e60eae (diff)
Used only the new format of processor/instructions/operands for x86.
git-svn-id: svn://svn.gna.org/svn/chrysalide/trunk@64 abbe820e-26c8-41b2-8c08-b7b2b41f8b0a
Diffstat (limited to 'src/arch/x86/processor.h')
-rw-r--r--src/arch/x86/processor.h26
1 files changed, 17 insertions, 9 deletions
diff --git a/src/arch/x86/processor.h b/src/arch/x86/processor.h
index 036966f..1014d11 100644
--- a/src/arch/x86/processor.h
+++ b/src/arch/x86/processor.h
@@ -25,24 +25,32 @@
#define _ARCH_X86_PROCESSOR_H
-#include "../instruction.h"
#include "../processor.h"
+#include "instruction.h"
-/* Définition générique d'une architecture */
-typedef struct _asm_x86_processor asm_x86_processor;
+#define G_TYPE_X86_PROCESSOR g_x86_processor_get_type()
+#define G_X86_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), g_x86_processor_get_type(), GX86Processor))
+#define G_IS_X86_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_x86_processor_get_type()))
+#define G_X86_PROCESSOR_GET_IFACE(inst) (G_TYPE_INSTANCE_GET_INTERFACE((inst), g_x86_processor_get_type(), GX86ProcessorIface))
-/* Crée le support de l'architecture x86. */
-asm_processor *create_x86_processor(void);
+/* Définition du processeur de la x86 (instance) */
+typedef struct _GX86Processor GX86Processor;
-/* Fournit la taille courante des opérandes pour x86. */
-AsmOperandSize get_x86_current_operand_size(const asm_x86_processor *);
+/* Définition du processeur de la x86 (classe) */
+typedef struct _GX86ProcessorClass GX86ProcessorClass;
-/* Fournit la taille supplantée des opérandes pour x86. */
-AsmOperandSize switch_x86_operand_size_if_needed(const asm_x86_processor *, const uint8_t *, off_t *);
+/* Indique le type défini par la GLib pour le processeur x86. */
+GType g_x86_processor_get_type(void);
+
+/* Crée le support de l'architecture x86. */
+GArchProcessor *g_x86_processor_new(void);
+
+/* Fournit la taille supplantée des opérandes pour x86. */
+AsmOperandSize g_x86_processor_get_operand_size(const GX86Processor *, X86Prefix);